@@ -23,8 +23,8 @@
 #include <QQuickItem>
 
 #include <kscreen/output.h>
+#include "qmloutput.h"
 
-class QMLOutput;
 class QQmlEngine;
 
 namespace KScreen {
@@ -40,10 +40,6 @@ class QMLScreen : public QQuickItem
                READ maxScreenSize
                CONSTANT)
 
-    Q_PROPERTY(QMLOutput* primaryOutput
-               READ primaryOutput
-               NOTIFY primaryOutputChanged)
-
     Q_PROPERTY(int connectedOutputsCount
                READ connectedOutputsCount
                NOTIFY connectedOutputsCountChanged)
@@ -63,7 +59,6 @@ class QMLScreen : public QQuickItem
     explicit QMLScreen(QQuickItem *parent = 0);
     virtual ~QMLScreen();
 
-    Q_INVOKABLE void addOutput(const KScreen::OutputPtr &output);
 
     int connectedOutputsCount() const;
     int enabledOutputsCount() const;
@@ -81,23 +76,30 @@ class QMLScreen : public QQuickItem
     void updateOutputsPlacement();
     void setEngine(QQmlEngine* engine);
 
+    void setActiveOutput(QMLOutput *output);
+
+  public Q_SLOTS:
+    void setActiveOutput() {
+        setActiveOutput(qobject_cast<QMLOutput*>(sender()));
+    }
+
+
   Q_SIGNALS:
     void connectedOutputsCountChanged();
     void enabledOutputsCountChanged();
-    void primaryOutputChanged();
 
     void outputScaleChanged();
 
     void focusedOutputChanged(QMLOutput *output);
 
   private Q_SLOTS:
+    void addOutput(const KScreen::OutputPtr &output);
+    void removeOutput(int outputId);
+
     void outputConnectedChanged();
     void outputEnabledChanged();
-    void outputPrimaryChanged();
     void outputPositionChanged();
 
-    void qmlOutputClicked();
-
     void viewSizeChanged();
 
   private:
